@@ -26,3 +26,5 @@ class GSHLSPlayer:
             if not ret:
                 break
             onframe(self.gsdbs, "hls_playlist", frame)
+        cap.release()
+        cv2.destroyAllWindows()
\ No newline at end of file
