@@ -5,6 +5,18 @@ import logging
 import socketio
 
 
+def geteventloop():
+    try:
+        loop = asyncio.get_event_loop()
+    except RuntimeError as e:
+        if str(e).startswith('There is no current event loop in thread'):
+            loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(loop)
+        else:
+            raise
+    return loop
+
+
 class GSCNodeFunctionReceiverSocket:
     @classmethod
     async def create(cls, sio, gsdbs, oncnodefunction):
@@ -44,7 +56,7 @@ class GSCNodeFunctionReceiver:
         self.oncnodefunction = oncnodefunction
 
     def startSocket(self):
-        loop = asyncio.get_event_loop()
+        loop = geteventloop()
         loop.run_until_complete(GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction))
         # asyncio.run(GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction))
 
@@ -88,8 +100,7 @@ class GSCNodeFunctionCaller:
         self.oncnodefunctionanswer = oncnodefunctionanswer
 
     def startSocket(self):
-        asyncio.run()
-        loop = asyncio.get_event_loop()
+        loop = geteventloop()
         loop.run_until_complete(
             GSCNodeFunctionCallerSocket.create(self.sio, self.gsdbs, self.oncnodefunctionanswer))
 
